@@ -1,10 +1,10 @@
 use cssparser::Parser;
 use markup5ever::{expanded_name, local_name, namespace_url, ns};
-use nalgebra::{DMatrix, Dynamic, VecStorage};
+use nalgebra::{DMatrix, Dyn, VecStorage};
 
 use crate::document::AcquiredNodes;
 use crate::drawing_ctx::DrawingCtx;
-use crate::element::{set_attribute, SetAttributes};
+use crate::element::{set_attribute, ElementTrait};
 use crate::error::*;
 use crate::node::{CascadedValues, Node};
 use crate::parsers::{NumberList, NumberOptionalNumber, Parse, ParseValue};
@@ -69,7 +69,7 @@ impl Default for ConvolveMatrix {
     }
 }
 
-impl SetAttributes for FeConvolveMatrix {
+impl ElementTrait for FeConvolveMatrix {
     fn set_attributes(&mut self, attrs: &Attributes, session: &Session) {
         self.params.in1 = self.base.parse_one_input(attrs, session);
 
@@ -209,11 +209,7 @@ impl ConvolveMatrix {
             });
         }
 
-        let matrix = DMatrix::from_data(VecStorage::new(
-            Dynamic::new(rows),
-            Dynamic::new(cols),
-            numbers,
-        ));
+        let matrix = DMatrix::from_data(VecStorage::new(Dyn(rows), Dyn(cols), numbers));
 
         let divisor = if self.divisor != 0.0 {
             self.divisor
