@@ -5,14 +5,14 @@ use std::sync::Arc;
 use cssparser::Parser;
 
 use crate::document::{AcquiredNodes, NodeId};
-use crate::drawing_ctx::ViewParams;
-use crate::element::Element;
+use crate::drawing_ctx::Viewport;
+use crate::element::ElementData;
 use crate::error::{AcquireError, NodeIdError, ParseError, ValueErrorKind};
 use crate::gradient::{ResolvedGradient, UserSpaceGradient};
+use crate::length::NormalizeValues;
 use crate::node::NodeBorrow;
 use crate::parsers::Parse;
 use crate::pattern::{ResolvedPattern, UserSpacePattern};
-use crate::properties::ComputedValues;
 use crate::rect::Rect;
 use crate::session::Session;
 use crate::unit_interval::UnitInterval;
@@ -145,8 +145,8 @@ impl PaintServer {
                     let node = acquired.get();
                     assert!(node.is_element());
 
-                    match *node.borrow_element() {
-                        Element::LinearGradient(ref g) => {
+                    match *node.borrow_element_data() {
+                        ElementData::LinearGradient(ref g) => {
                             g.resolve(node, acquired_nodes, opacity).map(|g| {
                                 Arc::new(PaintSource::Gradient(
                                     g,
@@ -154,7 +154,7 @@ impl PaintServer {
                                 ))
                             })
                         }
-                        Element::Pattern(ref p) => {
+                        ElementData::Pattern(ref p) => {
                             p.resolve(node, acquired_nodes, opacity, session).map(|p| {
                                 Arc::new(PaintSource::Pattern(
                                     p,
@@ -162,7 +162,7 @@ impl PaintServer {
                                 ))
                             })
                         }
-                        Element::RadialGradient(ref g) => {
+                        ElementData::RadialGradient(ref g) => {
                             g.resolve(node, acquired_nodes, opacity).map(|g| {
                                 Arc::new(PaintSource::Gradient(
                                     g,
@@ -243,15 +243,15 @@ impl PaintSource {
     pub fn to_user_space(
         &self,
         object_bbox: &Option<Rect>,
-        current_params: &ViewParams,
-        values: &ComputedValues,
+        viewport: &Viewport,
+        values: &NormalizeValues,
     ) -> UserSpacePaintSource {
         match *self {
             PaintSource::None => UserSpacePaintSource::None,
             PaintSource::SolidColor(c) => UserSpacePaintSource::SolidColor(c),
 
             PaintSource::Gradient(ref g, c) => {
-                match (g.to_user_space(object_bbox, current_params, values), c) {
+                match (g.to_user_space(object_bbox, viewport, values), c) {
                     (Some(gradient), c) => UserSpacePaintSource::Gradient(gradient, c),
                     (None, Some(c)) => UserSpacePaintSource::SolidColor(c),
                     (None, None) => UserSpacePaintSource::None,
@@ -259,7 +259,7 @@ impl PaintSource {
             }
 
             PaintSource::Pattern(ref p, c) => {
-                match (p.to_user_space(object_bbox, current_params, values), c) {
+                match (p.to_user_space(object_bbox, viewport, values), c) {
                     (Some(pattern), c) => UserSpacePaintSource::Pattern(pattern, c),
                     (None, Some(c)) => UserSpacePaintSource::SolidColor(c),
                     (None, None) => UserSpacePaintSource::None,
